==> reconciliation-manage-domain-0.0.34-sources.jar: com/xforceplus/reconciliationbill/entity/ReconBillItem.java <==
package com.xforceplus.reconciliationbill.entity;

import java.math.BigDecimal;
import java.time.LocalDateTime;
import java.io.Serializable;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;

/**
 * <p>
 * 
 * </p>
 *
 * @author wangzheng
 * @since 2020-07-13
 */
@Data
@EqualsAndHashCode(callSuper = false)
@Accessors(chain = true)
public class ReconBillItem implements Serializable {

  private static final long serialVersionUID=1L;

  private String salesbillItemId;

  private String salesbillItemNo;

  private String lockFlag;

  private Long id;

  private Long tenantId;

  private String tenantCode;

  private LocalDateTime createTime;

  private LocalDateTime updateTime;

  private Long createUserId;

  private Long updateUserId;

  private String createUserName;

  private String updateUserName;

  private String deleteFlag;

  private Long salesbillId;

  private String salesbillNo;

  private String businessBillType;

  private String invoiceType;

  private String itemCode;

  private String itemName;

  private String splitCode;

  private String itemTypeCode;

  private String itemShortName;

  private String itemSpec;

  private BigDecimal unitPriceWithTax;

  private BigDecimal unitPrice;

  private BigDecimal outterDiscountWithTax;

  private BigDecimal outterDiscountWithoutTax;

  private BigDecimal outterDiscountTax;

  private BigDecimal innerDiscountWithTax;

  private BigDecimal innerDiscountWithoutTax;

  private BigDecimal innerDiscountTax;

  private BigDecimal outterPrepayAmountWithTax;

  private BigDecimal outterPrepayAmountWithoutTax;

  private BigDecimal outterPrepayAmountTax;

  private BigDecimal innerPrepayAmountWithTax;

  private BigDecimal innerPrepayAmountWithoutTax;

  private BigDecimal innerPrepayAmountTax;

  private BigDecimal quantity;

  private String quantityUnit;

  private BigDecimal amountWithTax;

  private BigDecimal amountWithoutTax;

  private BigDecimal taxAmount;

  private BigDecimal abandonFreezeAmountWithTax;

  private BigDecimal abandonFreezeAmountWithoutTax;

  private BigDecimal abandonFreezeAmountTaxAmount;

  private BigDecimal taxRate;

  private String taxPre;

  private String taxPreCon;

  private String zeroTax;

  private BigDecimal deductions;

  private String status;

  private String goodsTaxNo;

  private String taxConvertCode;

  private String goodsNoVer;

  private String largeCategoryName;

  private String medianCategoryName;

  private String smallCategoryName;

  private Long origin;

  private String customerNo;

  private Long sysOrgId;

  private Long sellerTenantId;

  private Long purchaserTenantId;

  private String ext1;

  private String ext2;

  private String ext3;

  private String ext4;

  private String ext5;

  private String ext6;

  private String ext7;

  private String ext8;

  private String ext9;

  private String ext10;

  private String ext11;

  private String ext12;

  private String ext13;

  private String ext14;

  private String ext15;

  private String ext16;

  private String ext17;

  private String ext18;

  private String ext19;

  private String ext20;

  private Long billShipId;




        }

==> reconciliation-manage-domain-0.0.37-sources.jar: com/xforceplus/reconciliationbill/entity/ReconBillItem.java <==
package com.xforceplus.reconciliationbill.entity;

import java.math.BigDecimal;
import java.time.LocalDateTime;
import com.baomidou.mybatisplus.annotation.FieldFill;
import com.baomidou.mybatisplus.annotation.TableField;
import java.io.Serializable;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;

/**
 * <p>
 * 
 * </p>
 *
 * @author wangzheng
 * @since 2020-07-30
 */
@Data
@EqualsAndHashCode(callSuper = false)
@Accessors(chain = true)
public class ReconBillItem implements Serializable {

  private static final long serialVersionUID=1L;

  private String salesbillItemId;

  private String salesbillItemNo;

  private String lockFlag;

  private Long id;

  @TableField(fill = FieldFill.INSERT)
  private Long tenantId;

  @TableField(fill = FieldFill.INSERT)
  private String tenantCode;

  @TableField(fill = FieldFill.INSERT)
  private LocalDateTime createTime;

  @TableField(fill = FieldFill.INSERT_UPDATE)
  private LocalDateTime updateTime;

  @TableField(fill = FieldFill.INSERT)
  private Long createUserId;

  @TableField(fill = FieldFill.INSERT_UPDATE)
  private Long updateUserId;

  @TableField(fill = FieldFill.INSERT)
  private String createUserName;

  @TableField(fill = FieldFill.INSERT_UPDATE)
  private String updateUserName;

  @TableField(fill = FieldFill.INSERT)
  private String deleteFlag;

  private Long salesbillId;

  private String salesbillNo;

  private String businessBillType;

  private String invoiceType;

  private String itemCode;

  private String itemName;

  private String splitCode;

  private String itemTypeCode;

  private String itemShortName;

  private String itemSpec;

  private BigDecimal unitPriceWithTax;

  private BigDecimal unitPrice;

  private BigDecimal outterDiscountWithTax;

  private BigDecimal outterDiscountWithoutTax;

  private BigDecimal outterDiscountTax;

  private BigDecimal innerDiscountWithTax;

  private BigDecimal innerDiscountWithoutTax;

  private BigDecimal innerDiscountTax;

  private BigDecimal outterPrepayAmountWithTax;

  private BigDecimal outterPrepayAmountWithoutTax;

  private BigDecimal outterPrepayAmountTax;

  private BigDecimal innerPrepayAmountWithTax;

  private BigDecimal innerPrepayAmountWithoutTax;

  private BigDecimal innerPrepayAmountTax;

  private BigDecimal quantity;

  private String quantityUnit;

  private BigDecimal amountWithTax;

  private BigDecimal amountWithoutTax;

  private BigDecimal taxAmount;

  private BigDecimal abandonFreezeAmountWithTax;

  private BigDecimal abandonFreezeAmountWithoutTax;

  private BigDecimal abandonFreezeAmountTaxAmount;

  private BigDecimal taxRate;

  private String taxPre;

  private String taxPreCon;

  private String zeroTax;

  private BigDecimal deductions;

  private String status;

  private String goodsTaxNo;

  private String taxConvertCode;

  private String goodsNoVer;

  private String largeCategoryName;

  private String medianCategoryName;

  private String smallCategoryName;

  private Long origin;

  private String customerNo;

  private Long sysOrgId;

  private Long sellerTenantId;

  private Long purchaserTenantId;

  private String ext1;

  private String ext2;

  private String ext3;

  private String ext4;

  private String ext5;

  private String ext6;

  private String ext7;

  private String ext8;

  private String ext9;

  private String ext10;

  private String ext11;

  private String ext12;

  private String ext13;

  private String ext14;

  private String ext15;

  private String ext16;

  private String ext17;

  private String ext18;

  private String ext19;

  private String ext20;

  private Long billShipId;




        }
